@@ -105,10 +105,22 @@ def chrome_on_linux_path(chromium_ok=False, browser_type=None):
         return ""
     if os_name() != OSType.LINUX:
         return ""
-    paths = ["/bin/google-chrome", "/bin/google-chrome-stable"]
+    paths = [
+        "/bin/google-chrome",
+        "/bin/google-chrome-stable",
+        "/usr/bin/google-chrome",
+        "/usr/bin/google-chrome-stable"
+    ]
     for path in paths:
-        if os.path.exists(path) and os.access(path, os.X_OK):
-            return path
+        try:
+            if (
+                os.path.exists(path)
+                and os.access(path, os.R_OK)
+                and os.access(path, os.X_OK)
+            ):
+                return path
+        except Exception:
+            pass
     paths = os.environ["PATH"].split(os.pathsep)
     binaries = []
     binaries.append("google-chrome")
@@ -122,13 +134,32 @@ def chrome_on_linux_path(chromium_ok=False, browser_type=None):
     for binary in binaries:
         for path in paths:
             full_path = os.path.join(path, binary)
-            if os.path.exists(full_path) and os.access(full_path, os.X_OK):
-                return full_path
+            try:
+                if (
+                    os.path.exists(full_path)
+                    and os.access(full_path, os.R_OK)
+                    and os.access(full_path, os.X_OK)
+                ):
+                    return full_path
+            except Exception:
+                pass
     if chromium_ok:
-        paths = ["/bin/chromium", "/bin/chromium-browser"]
+        paths = [
+            "/bin/chromium",
+            "/bin/chromium-browser",
+            "/usr/bin/chromium",
+            "/usr/bin/chromium-browser"
+        ]
         for path in paths:
-            if os.path.exists(path) and os.access(path, os.X_OK):
-                return path
+            try:
+                if (
+                    os.path.exists(path)
+                    and os.access(path, os.R_OK)
+                    and os.access(path, os.X_OK)
+                ):
+                    return path
+            except Exception:
+                pass
     return "/usr/bin/google-chrome"
 
 
@@ -278,6 +309,7 @@ def opera_on_windows_path(browser_type=None):
         ),
     ):
         for subitem in (
+            "Programs/Opera",
             "Opera",
             "Opera/Application",
         ):
@@ -328,17 +360,19 @@ def comet_on_windows_path(browser_type=None):
     for item in map(
         os.environ.get,
         (
+            "LOCALAPPDATA",
             "PROGRAMFILES",
             "PROGRAMFILES(X86)",
-            "LOCALAPPDATA",
             "PROGRAMW6432",
         ),
     ):
         for subitem in (
+            "Perplexity/Comet/Application",
             "Comet/Application",
+            "Programs/Comet",
         ):
             try:
-                candidates.append(os.sep.join((item, subitem, "Comet.exe")))
+                candidates.append(os.sep.join((item, subitem, "comet.exe")))
             except TypeError:
                 pass
     for candidate in candidates:
@@ -356,17 +390,19 @@ def atlas_on_windows_path(browser_type=None):
     for item in map(
         os.environ.get,
         (
+            "LOCALAPPDATA",
             "PROGRAMFILES",
             "PROGRAMFILES(X86)",
-            "LOCALAPPDATA",
             "PROGRAMW6432",
         ),
     ):
         for subitem in (
+            "OpenAI/Atlas/Application",
             "Atlas/Application",
+            "Programs/Atlas",
         ):
             try:
-                candidates.append(os.sep.join((item, subitem, "Atlas.exe")))
+                candidates.append(os.sep.join((item, subitem, "atlas.exe")))
             except TypeError:
                 pass
     for candidate in candidates:
@@ -426,8 +462,8 @@ def get_binary_location(browser_type, chromium_ok=False):
         },
         ChromeType.ATLAS: {
             OSType.LINUX: atlas_on_linux_path(browser_type),
-            OSType.MAC: r"/Applications/Atlas.app"
-                        r"/Contents/MacOS/Atlas",
+            OSType.MAC: r"/Applications/ChatGPT Atlas.app"
+                        r"/Contents/MacOS/ChatGPT Atlas",
             OSType.WIN: atlas_on_windows_path(browser_type),
         },
     }
