@@ -1134,10 +1134,9 @@ def export_tour(tour_steps, name=None, filename="my_tour.js", url=None):
             os.makedirs(exported_tours_folder)
         except Exception:
             pass
-    import codecs
 
     file_path = exported_tours_folder + "/" + filename
-    out_file = codecs.open(file_path, "w+", encoding="utf-8")
+    out_file = open(file_path, mode="w+", encoding="utf-8")
     out_file.writelines(instructions)
     out_file.close()
     print("\n>>> [%s] was saved!\n" % file_path)
