@@ -1530,7 +1530,7 @@ def save_page_source(driver, name, folder=None):
     rendered_source = log_helper.get_html_source_with_base_href(
         driver, page_source
     )
-    html_file = open(html_file_path, "w+", "utf-8")
+    html_file = open(html_file_path, mode="w+", encoding="utf-8")
     html_file.write(rendered_source)
     html_file.close()
 
@@ -1756,6 +1756,29 @@ def open_url(driver, url):
     if __is_cdp_swap_needed(driver):
         driver.cdp.open(url)
         return
+    elif (
+        hasattr(driver, "_is_using_uc")
+        and driver._is_using_uc
+        # and hasattr(driver, "_is_using_auth")
+        # and driver._is_using_auth
+        and (
+            not hasattr(driver, "_is_using_cdp")
+            or not driver._is_using_cdp
+        )
+    ):
+        # Auth in UC Mode requires CDP Mode
+        # (and now we're always forcing it)
+        driver.uc_activate_cdp_mode(url)
+        return
+    elif (
+        hasattr(driver, "_is_using_uc")
+        and driver._is_using_uc
+        and hasattr(driver, "_is_using_cdp")
+        and driver._is_using_cdp
+    ):
+        driver.disconnect()
+        driver.cdp.open(url)
+        return
     url = str(url).strip()  # Remove leading and trailing whitespace
     if not page_utils.looks_like_a_page_url(url):
         if page_utils.is_valid_url("https://" + url):
