@@ -10,8 +10,8 @@ var cssPathById = function(el) {
         var selector = el.nodeName.toLowerCase();
         if (el.id) {
             elid = el.id;
-            if (elid.includes(',') || elid.includes('.') ||
-                elid.includes('(') || elid.includes(')') || hasNumber(elid[0]))
+            if (/\s/.test(elid) || elid.includes(',') || elid.includes('.') ||
+                elid.includes('(') || elid.includes(':') || hasDigit(elid[0]))
                 return cssPathByAttribute(el, 'id');
             selector += '#' + elid;
             path.unshift(selector);
@@ -40,10 +40,8 @@ var cssPathByAttribute = function(el, attr) {
             !el.getAttribute(attr).includes('\n'))
         {
             the_attr = el.getAttribute(attr);
-            if (the_attr.includes('"'))
-                the_attr = the_attr.replace('"', '\\"');
-            if (the_attr.includes("'"))
-                the_attr = the_attr.replace("'", "\\'");
+            the_attr = the_attr.replaceAll('"', '\\"');
+            the_attr = the_attr.replaceAll("'", "\\'");
             selector += '[' + attr + '="' + the_attr + '"]';
             path.unshift(selector);
             break;
@@ -89,8 +87,6 @@ var cssPathByClass = function(el) {
     return path.join(' > ');
 };
 var ssOccurrences = function(string, subString, allowOverlapping) {
-    string += '';
-    subString += '';
     if (subString.length <= 0)
         return (string.length + 1);
     var n = 0;
@@ -103,9 +99,12 @@ var ssOccurrences = function(string, subString, allowOverlapping) {
     }
     return n;
 };
-function hasNumber(str) {
+function hasDigit(str) {
     return /\d/.test(str);
 };
+function isGen(str) {
+    return /[_-]\d/.test(str) || /\d[a-z]/.test(str);
+};
 function tagName(el) {
     return el.tagName.toLowerCase();
 };
@@ -123,10 +122,9 @@ function turnIntoParentAsNeeded(el) {
 var getBestSelector = function(el) {
     if (!(el instanceof Element)) return;
     el = turnIntoParentAsNeeded(el);
-    child_sep = ' > ';
-    selector_by_id = cssPathById(el);
-    if (!selector_by_id.includes(child_sep)) return selector_by_id;
-    child_count_by_id = ssOccurrences(selector_by_id, child_sep);
+    sel_by_id = cssPathById(el);
+    if (!sel_by_id.includes(' > ') && !isGen(sel_by_id)) return sel_by_id;
+    child_count_by_id = ssOccurrences(sel_by_id, ' > ');
     selector_by_class = cssPathByClass(el);
     tag_name = tagName(el);
     non_id_attributes = [];
@@ -147,21 +145,26 @@ var getBestSelector = function(el) {
     non_id_attributes.push('data-cy');
     non_id_attributes.push('data-action');
     non_id_attributes.push('data-target');
-    non_id_attributes.push('data-content');
     non_id_attributes.push('data-tooltip');
     non_id_attributes.push('alt');
     non_id_attributes.push('title');
     non_id_attributes.push('heading');
     non_id_attributes.push('translate');
     non_id_attributes.push('aria-label');
+    non_id_attributes.push('aria-describedby');
+    non_id_attributes.push('rel');
     non_id_attributes.push('ng-model');
     non_id_attributes.push('ng-href');
     non_id_attributes.push('href');
     non_id_attributes.push('label');
+    non_id_attributes.push('data-content');
+    non_id_attributes.push('data-tip');
+    non_id_attributes.push('data-for');
     non_id_attributes.push('class');
     non_id_attributes.push('for');
     non_id_attributes.push('placeholder');
     non_id_attributes.push('value');
+    non_id_attributes.push('ng-click');
     non_id_attributes.push('ng-if');
     non_id_attributes.push('src');
     selector_by_attr = [];
@@ -175,15 +178,14 @@ var getBestSelector = function(el) {
         else selector_by_attr[i] = cssPathByAttribute(el, n_i_attr);
         all_by_attr[i] = document.querySelectorAll(selector_by_attr[i]);
         num_by_attr[i] = all_by_attr[i].length;
-        if (!selector_by_attr[i].includes(child_sep) &&
+        if (!selector_by_attr[i].includes(' > ') &&
             ((num_by_attr[i] == 1) || (el == all_by_attr[i][0])))
         {
-            if (n_i_attr == 'aria-label' || n_i_attr == 'for')
-                if (hasNumber(selector_by_attr[i]))
-                    continue;
+            if (n_i_attr.startsWith('aria') || n_i_attr == 'for')
+                if (hasDigit(selector_by_attr[i])) continue;
             return selector_by_attr[i];
         }
-        child_count_by_attr[i] = ssOccurrences(selector_by_attr[i], child_sep);
+        child_count_by_attr[i] = ssOccurrences(selector_by_attr[i], ' > ');
     }
     basic_tags = [];
     basic_tags.push('h1');
@@ -201,23 +203,24 @@ var getBestSelector = function(el) {
     contains_tags = [];
     contains_tags.push('a');
     contains_tags.push('b');
-    contains_tags.push('i');
     contains_tags.push('h1');
     contains_tags.push('h2');
     contains_tags.push('h3');
     contains_tags.push('h4');
     contains_tags.push('h5');
+    contains_tags.push('code');
+    contains_tags.push('mark');
+    contains_tags.push('button');
+    contains_tags.push('label');
+    contains_tags.push('legend');
     contains_tags.push('li');
     contains_tags.push('td');
     contains_tags.push('th');
-    contains_tags.push('code');
-    contains_tags.push('mark');
-    contains_tags.push('label');
+    contains_tags.push('i');
     contains_tags.push('small');
-    contains_tags.push('button');
-    contains_tags.push('legend');
     contains_tags.push('strong');
     contains_tags.push('summary');
+    contains_tags.push('span');
     all_by_tag = [];
     text_content = '';
     if (el.textContent)
@@ -239,9 +242,9 @@ var getBestSelector = function(el) {
             }
         }
     }
-    best_selector = selector_by_id;
+    best_selector = sel_by_id;
     lowest_child_count = child_count_by_id;
-    child_count_by_class = ssOccurrences(selector_by_class, child_sep);
+    child_count_by_class = ssOccurrences(selector_by_class, ' > ');
     if (child_count_by_class < lowest_child_count) {
         best_selector = selector_by_class;
         lowest_child_count = child_count_by_class;
@@ -262,6 +265,14 @@ var getBestSelector = function(el) {
     return best_selector;
 };
 
+function useHref(tag_name, el) {
+    return (tag_name === 'a' && el.hasAttribute('href') &&
+            el.getAttribute('href').length > 0 && el.origin != 'null');
+};
+function saveRecordedActions() {
+    json_rec_act = JSON.stringify(document.recorded_actions);
+    sessionStorage.setItem('recorded_actions', json_rec_act);
+};
 function new_tab_on_new_origin() {
     var AllAnchorTags = document.getElementsByTagName('a');
     for (var i = 0; i < AllAnchorTags.length; i++) {
@@ -309,7 +320,7 @@ var reset_recorder_state = function() {
     document.recorded_actions = [];
     sessionStorage.setItem('pause_recorder', 'no');
     sessionStorage.setItem('recorder_mode', '1');
-    sessionStorage.setItem('recorder_title', document.title)
+    sessionStorage.setItem('recorder_title', document.title);
     const d_now = Date.now();
     document.recorder_last_mouseup = d_now;
     w_orig = window.location.origin;
@@ -323,8 +334,7 @@ var reset_recorder_state = function() {
         sessionStorage.setItem('recorder_activated', 'yes');
         document.recorded_actions.push(['begin', w_orig, w_href, d_now]);
     }
-    json_rec_act = JSON.stringify(document.recorded_actions);
-    sessionStorage.setItem('recorded_actions', json_rec_act);
+    saveRecordedActions();
     return;
 };
 reset_recorder_state();
@@ -366,7 +376,6 @@ window.addEventListener('blur', () => {
         Date.now() - document.recorder_last_mouseup > 32)
     {
         const selector = getBestSelector(el);
-        ra_len = document.recorded_actions.length;
         const el_cw = el.contentWindow;
         origin = window.location.origin;
         if (el.hasAttribute('src') && el.getAttribute('src').length > 0) {
@@ -378,14 +387,19 @@ window.addEventListener('blur', () => {
         document.recorded_actions.push(['sw_fr', selector, origin, d_now]);
         if (skip_open)
             document.recorded_actions.push(['sk_fo', '', origin, d_now2]);
-        json_rec_act = JSON.stringify(document.recorded_actions);
-        sessionStorage.setItem('recorded_actions', json_rec_act);
+        saveRecordedActions();
     }
     });
 }, { once: false });
 document.body.addEventListener('click', function (event) {
     // do nothing
 });
+document.body.addEventListener('dblclick', function (event) {
+    reset_if_recorder_undefined();
+    if (sessionStorage.getItem('pause_recorder') === 'yes') return;
+    document.recorded_actions.push(['dbclk', '', '', Date.now()+1]);
+    saveRecordedActions();
+});
 document.body.addEventListener('submit', function (event) {
     reset_if_recorder_undefined();
     if (sessionStorage.getItem('pause_recorder') === 'yes') return;
@@ -399,8 +413,7 @@ document.body.addEventListener('submit', function (event) {
         text = document.recorded_actions[ra_len-1][2] + '\n';
         document.recorded_actions.pop();
         document.recorded_actions.push(['input', selector, text, d_now]);
-        json_rec_act = JSON.stringify(document.recorded_actions);
-        sessionStorage.setItem('recorded_actions', json_rec_act);
+        saveRecordedActions();
     }
 });
 document.body.addEventListener('formdata', function (event) {
@@ -416,8 +429,7 @@ document.body.addEventListener('formdata', function (event) {
         text = document.querySelector(selector).value + '\n';
         document.recorded_actions.pop();
         document.recorded_actions.push(['input', selector, text, d_now]);
-        json_rec_act = JSON.stringify(document.recorded_actions);
-        sessionStorage.setItem('recorded_actions', json_rec_act);
+        saveRecordedActions();
     }
 });
 document.body.addEventListener('dragstart', function (event) {
@@ -438,8 +450,7 @@ document.body.addEventListener('dragstart', function (event) {
     if (el.draggable === true) {
         document.recorded_actions.push(['drags', selector, '', d_now]);
     }
-    json_rec_act = JSON.stringify(document.recorded_actions);
-    sessionStorage.setItem('recorded_actions', json_rec_act);
+    saveRecordedActions();
 });
 document.body.addEventListener('dragend', function (event) {
     reset_if_recorder_undefined();
@@ -448,8 +459,7 @@ document.body.addEventListener('dragend', function (event) {
     if (ra_len > 0 && document.recorded_actions[ra_len-1][0] === 'drags')
     {
         document.recorded_actions.pop();
-        json_rec_act = JSON.stringify(document.recorded_actions);
-        sessionStorage.setItem('recorded_actions', json_rec_act);
+        saveRecordedActions();
     }
 });
 document.body.addEventListener('drop', function (event) {
@@ -464,8 +474,7 @@ document.body.addEventListener('drop', function (event) {
         drg_s = document.recorded_actions[ra_len-1][1];
         document.recorded_actions.pop();
         document.recorded_actions.push(['ddrop', drg_s, selector, d_now]);
-        json_rec_act = JSON.stringify(document.recorded_actions);
-        sessionStorage.setItem('recorded_actions', json_rec_act);
+        saveRecordedActions();
     }
 });
 document.body.addEventListener('change', function (event) {
@@ -520,11 +529,11 @@ document.body.addEventListener('change', function (event) {
         document.recorded_actions.push(['c_box', selector, 'yes', d_now]);
     else if (tag_name === 'input' && e_type === 'checkbox' && !el.checked)
         document.recorded_actions.push(['c_box', selector, 'no', d_now]);
-    json_rec_act = JSON.stringify(document.recorded_actions);
-    sessionStorage.setItem('recorded_actions', json_rec_act);
+    saveRecordedActions();
 });
 document.body.addEventListener('mousedown', function (event) {
     reset_if_recorder_undefined();
+    new_tab_on_new_origin();
     if (sessionStorage.getItem('pause_recorder') === 'yes') return;
     const d_now = Date.now();
     el = event.target;
@@ -548,8 +557,7 @@ document.body.addEventListener('mousedown', function (event) {
             rec_mode === '3' && sel_has_contains && text === t_con.trim()))
         {
             document.recorded_actions.push(['as_el', selector, origin, d_now]);
-            json_rec_act = JSON.stringify(document.recorded_actions);
-            sessionStorage.setItem('recorded_actions', json_rec_act);
+            saveRecordedActions();
             return;
         }
         else if (rec_mode === '3') {
@@ -566,8 +574,7 @@ document.body.addEventListener('mousedown', function (event) {
             }
             tex_sel = [text, selector];
             document.recorded_actions.push([action, tex_sel, origin, d_now]);
-            json_rec_act = JSON.stringify(document.recorded_actions);
-            sessionStorage.setItem('recorded_actions', json_rec_act);
+            saveRecordedActions();
             return;
         }
     }
@@ -578,8 +585,7 @@ document.body.addEventListener('mousedown', function (event) {
     }
     else
         document.recorded_actions.push(['mo_dn', selector, '', d_now]);
-    json_rec_act = JSON.stringify(document.recorded_actions);
-    sessionStorage.setItem('recorded_actions', json_rec_act);
+    saveRecordedActions();
 });
 document.body.addEventListener('mouseup', function (event) {
     reset_if_recorder_undefined();
@@ -606,30 +612,20 @@ document.body.addEventListener('mouseup', function (event) {
          tag_name === 'a' || parent_tag_name === 'a') && tag_name !== 'select')
     {
         href = '';
-        if (tag_name === 'a' &&
-            el.hasAttribute('href') &&
-            el.getAttribute('href').length > 0 &&
-            el.origin != 'null')
+        if (useHref(tag_name, el))
         {
             href = el.href; origin = el.origin;
         }
-        else if (parent_tag_name === 'a' &&
-            parent_el.hasAttribute('href') &&
-            parent_el.getAttribute('href').length > 0 &&
-            parent_el.origin != 'null')
+        else if (useHref(parent_tag_name, parent_el))
         {
             href = parent_el.href; origin = parent_el.origin;
         }
-        else if (grand_tag_name === 'a' &&
-            grand_el.hasAttribute('href') &&
-            grand_el.getAttribute('href').length > 0 &&
-            grand_el.origin != 'null')
+        else if (useHref(grand_tag_name, grand_el))
         {
             href = grand_el.href; origin = grand_el.origin;
         }
         document.recorded_actions.pop();
-        child_sep = ' > ';
-        child_count = ssOccurrences(selector, child_sep);
+        child_count = ssOccurrences(selector, ' > ');
         if ((tag_name === "a" && !el.hasAttribute('onclick') &&
              child_count > 0 && href.length > 0) ||
             (parent_tag_name === "a" && href.length > 0 &&
@@ -682,8 +678,7 @@ document.body.addEventListener('mouseup', function (event) {
         // accidental drag&drop
         document.recorded_actions.pop();
     }
-    json_rec_act = JSON.stringify(document.recorded_actions);
-    sessionStorage.setItem('recorded_actions', json_rec_act);
+    saveRecordedActions();
 });
 document.body.addEventListener('contextmenu', function (event) {
     reset_if_recorder_undefined();
@@ -696,12 +691,26 @@ document.body.addEventListener('contextmenu', function (event) {
         document.recorded_actions[ra_len-1][1] === selector)
     {
         document.recorded_actions.pop();
-        json_rec_act = JSON.stringify(document.recorded_actions);
-        sessionStorage.setItem('recorded_actions', json_rec_act);
+        saveRecordedActions();
     }
 });
 document.body.addEventListener('keydown', function (event) {
-    // do nothing
+    reset_if_recorder_undefined();
+    if (sessionStorage.getItem('pause_recorder') === 'yes') return;
+    if (document.recorded_actions.length == 0) return;
+    const el = event.target;
+    const selector = getBestSelector(el);
+    const d_now = Date.now();
+    const tag_name = tagName(el);
+    const l_key = event.key.toLowerCase();
+    if (l_key === 'enter' && (tag_name === 'button' || tag_name === 'a'))
+    {
+        href = '';
+        if (useHref(tag_name, el))
+            href = el.href;
+        document.recorded_actions.push(['click', selector, href, d_now]);
+        saveRecordedActions();
+    }
 });
 document.body.addEventListener('keyup', function (event) {
     reset_if_recorder_undefined();
@@ -768,7 +777,8 @@ document.body.addEventListener('keyup', function (event) {
         else if (ra_len > 0 &&
             document.recorded_actions[ra_len-1][0] === 'input' &&
             document.recorded_actions[ra_len-1][1] === selector &&
-            !document.recorded_actions[ra_len-1][2].endsWith('\n'))
+            !document.recorded_actions[ra_len-1][2].endsWith('\n') &&
+            l_key !== 'tab')
         {
             document.recorded_actions.pop();
         }
@@ -779,13 +789,12 @@ document.body.addEventListener('keyup', function (event) {
         {
             skip_input = true;
         }
-        if (!skip_input && !el.hasAttribute('readonly')) {
+        if (!skip_input && !el.hasAttribute('readonly') && l_key !== 'tab') {
             document.recorded_actions.push(
                 ['input', selector, el.value, d_now]);
         }
     }
-    json_rec_act = JSON.stringify(document.recorded_actions);
-    sessionStorage.setItem('recorded_actions', json_rec_act);
+    saveRecordedActions();
 });
 set_border('#F43344');
 """
