@@ -455,8 +455,6 @@ def Driver(
         )
     if sb_config._browser_shortcut:
         browser = sb_config._browser_shortcut
-    if browser in constants.ChromiumSubs.chromium_subs:
-        browser = "chrome"  # Still uses chromedriver
     if headless is None:
         if "--headless" in sys_argv:
             headless = True
@@ -744,7 +742,10 @@ def Driver(
         uc_cdp_events = True
     else:
         uc_cdp_events = False
-    if undetectable and browser != "chrome":
+    if (
+        undetectable
+        and browser not in ["chrome", "opera", "brave", "comet", "atlas"]
+    ):
         message = (
             '\n  Undetected-Chromedriver Mode ONLY supports Chrome!'
             '\n  ("uc=True" / "undetectable=True" / "--uc")'
@@ -953,6 +954,10 @@ def Driver(
                     driver_version = None
                 break
             count += 1
+    if browser in constants.ChromiumSubs.chromium_subs:
+        if not binary_location:
+            browser = "chrome"  # Still uses chromedriver
+            sb_config._browser_shortcut = browser
     browser_name = browser
 
     # Launch a web browser
