@@ -10,13 +10,13 @@ Example -->
 ```python
 from seleniumbase import SB
 
-with SB(uc=True) as sb:  # Many args! Eg. SB(browser="edge")
-    sb.open("https://google.com/ncr")
-    sb.type('[name="q"]', "SeleniumBase on GitHub\n")
-    sb.click('a[href*="github.com/seleniumbase"]')
-    sb.highlight("div.Layout-main")
-    sb.highlight("div.Layout-sidebar")
-    sb.sleep(0.5)
+with SB(uc=True, test=True) as sb:
+    url = "https://google.com/ncr"
+    sb.activate_cdp_mode(url)
+    sb.type('[title="Search"]', "SeleniumBase GitHub page")
+    sb.click("div:not([jsname]) > * > input")
+    sb.sleep(2)
+    print(sb.get_page_title())
 ```
 
 # (The browser exits automatically after the "with" block ends.)
@@ -144,14 +144,13 @@ def SB(
     .. code-block:: python
         from seleniumbase import SB
 
-        with SB() as sb:  # Many args! Eg. SB(browser="edge")
-            sb.open("https://google.com/ncr")
-            sb.type('[name="q"]', "SeleniumBase on GitHub")
-            sb.submit('[name="q"]')
-            sb.click('a[href*="github.com/seleniumbase"]')
-            sb.highlight("div.Layout-main")
-            sb.highlight("div.Layout-sidebar")
-            sb.sleep(0.5)
+        with SB(uc=True, test=True) as sb:
+            url = "https://google.com/ncr"
+            sb.activate_cdp_mode(url)
+            sb.type('[title="Search"]', "SeleniumBase GitHub page")
+            sb.click("div:not([jsname]) > * > input")
+            sb.sleep(2)
+            print(sb.get_page_title())
 
     Optional Parameters:
     --------------------
@@ -1132,8 +1131,6 @@ def SB(
     sb_config.browser = browser
     if sb_config._browser_shortcut:
         sb_config.browser = sb_config._browser_shortcut
-    if sb_config.browser in constants.ChromiumSubs.chromium_subs:
-        sb_config.browser = "chrome"  # Still uses chromedriver
     if not hasattr(sb_config, "is_behave"):
         sb_config.is_behave = False
     if not hasattr(sb_config, "is_pytest"):
@@ -1242,6 +1239,10 @@ def SB(
     sb_config.interval = interval
     sb_config.cap_file = cap_file
     sb_config.cap_string = cap_string
+    if sb_config.browser in constants.ChromiumSubs.chromium_subs:
+        if not sb_config.binary_location:
+            sb_config.browser = "chrome"  # Still uses chromedriver
+            sb_config._browser_shortcut = sb_config.browser
 
     sb = BaseCase()
     sb.with_testing_base = sb_config.with_testing_base
