@@ -7,7 +7,6 @@ import json
 import logging
 import sys
 import types
-from asyncio import iscoroutine, iscoroutinefunction
 from typing import (
     Optional,
     Generator,
@@ -371,8 +370,8 @@ class Connection(metaclass=CantTouchThis):
 
     async def set_geolocation(self, geolocation: Optional[tuple] = None):
         """Sets the User Agent via set_geolocation_override."""
-        await self.send(cdp.browser.grant_permissions(
-            permissions=["geolocation"],
+        await self.send(cdp.browser.set_permission(
+            permission={"name": "geolocation"}, setting="granted"
         ))
         await self.send(cdp.emulation.set_geolocation_override(
             latitude=geolocation[0],
@@ -380,36 +379,6 @@ class Connection(metaclass=CantTouchThis):
             accuracy=100,
         ))
 
-    async def set_auth(self, username, password, tab):
-        async def auth_challenge_handler(event: cdp.fetch.AuthRequired):
-            await tab.send(
-                cdp.fetch.continue_with_auth(
-                    request_id=event.request_id,
-                    auth_challenge_response=cdp.fetch.AuthChallengeResponse(
-                        response="ProvideCredentials",
-                        username=username,
-                        password=password,
-                    ),
-                )
-            )
-
-        async def req_paused(event: cdp.fetch.RequestPaused):
-            await tab.send(
-                cdp.fetch.continue_request(request_id=event.request_id)
-            )
-
-        tab.add_handler(
-            cdp.fetch.RequestPaused,
-            lambda event: asyncio.create_task(req_paused(event)),
-        )
-
-        tab.add_handler(
-            cdp.fetch.AuthRequired,
-            lambda event: asyncio.create_task(auth_challenge_handler(event)),
-        )
-
-        await tab.send(cdp.fetch.enable(handle_auth_requests=True))
-
     def __getattr__(self, item):
         """:meta private:"""
         try:
@@ -666,8 +635,8 @@ class Listener:
                     for callback in callbacks:
                         try:
                             if (
-                                iscoroutinefunction(callback)
-                                or iscoroutine(callback)
+                                inspect.iscoroutinefunction(callback)
+                                or inspect.iscoroutine(callback)
                             ):
                                 try:
                                     await callback(event, self.connection)
