@@ -244,23 +244,7 @@ class Tab(Connection):
          Raise timeout exception when after this many seconds nothing is found.
         :type timeout: float,int
         """
-        loop = asyncio.get_running_loop()
-        start_time = loop.time()
-        selector = selector.strip()
-        item = None
-        try:
-            item = await self.query_selector(selector)
-        except (Exception, TypeError):
-            pass
-        while not item:
-            await self
-            item = await self.query_selector(selector)
-            if loop.time() - start_time > timeout:
-                raise asyncio.TimeoutError(
-                    "Time ran out while waiting for: {%s}" % selector
-                )
-            await self.sleep(0.5)
-        return item
+        return await self.wait_for(selector=selector, timeout=timeout)
 
     async def find_all(
         self,
@@ -705,10 +689,12 @@ class Tab(Connection):
             raise ProtocolException(errors)
         if remote_object:
             if return_by_value:
-                if remote_object.value:
+                if remote_object.value is not None:
                     return remote_object.value
             else:
-                return remote_object, errors
+                if remote_object.deep_serialized_value is not None:
+                    return remote_object.deep_serialized_value.value
+        return None
 
     async def js_dumps(
         self, obj_name: str, return_by_value: Optional[bool] = True
@@ -899,7 +885,10 @@ class Tab(Connection):
         """Gets the current page source content (html)"""
         doc: cdp.dom.Node = await self.send(cdp.dom.get_document(-1, True))
         return await self.send(
-            cdp.dom.get_outer_html(backend_node_id=doc.backend_node_id)
+            cdp.dom.get_outer_html(
+                backend_node_id=doc.backend_node_id,
+                include_shadow_dom=True,
+            )
         )
 
     async def maximize(self):
@@ -1075,7 +1064,7 @@ class Tab(Connection):
                     raise asyncio.TimeoutError(
                         "Time ran out while waiting for: {%s}" % selector
                     )
-                await self.sleep(0.5)
+                await self.sleep(0.068)
             return item
         if text:
             item = await self.find_element_by_text(text)
@@ -1085,7 +1074,7 @@ class Tab(Connection):
                     raise asyncio.TimeoutError(
                         "Time ran out while waiting for: {%s}" % text
                     )
-                await self.sleep(0.5)
+                await self.sleep(0.068)
             return item
 
     async def download_file(
@@ -1365,7 +1354,9 @@ class Tab(Connection):
         :param selector: css selector string
         :type selector: str
         """
-        return self.wait_for(text, selector, timeout)
+        return self.wait_for(
+            selector=selector, text=text, timeout=timeout
+        )
 
     def __eq__(self, other: Tab):
         try:
