@@ -1,4 +1,3 @@
-import codecs
 import os
 import subprocess
 import sys
@@ -88,14 +87,14 @@ def main():
     data = []
     data.append(server_ip)
     file_path = os.path.join(dir_path, "ip_of_grid_hub.dat")
-    file = codecs.open(file_path, "w+", "utf-8")
+    file = open(file_path, mode="w+", encoding="utf-8")
     file.writelines("\r\n".join(data))
     file.close()
 
     data = []
     data.append(verbose)
     file_path = os.path.join(dir_path, "verbose_node_server.dat")
-    file = codecs.open(file_path, "w+", "utf-8")
+    file = open(file_path, mode="w+", encoding="utf-8")
     file.writelines("\r\n".join(data))
     file.close()
 
